@@ -6,7 +6,7 @@ modify it under the terms of the GNU General Public License as
 published by the Free Software Foundation; either version 2 of
 the License or (at your option) version 3 or any later version
 accepted by the membership of KDE e.V. (or its successor approved
-by the membership of KDE e.V.), which shall act as a proxy 
+by the membership of KDE e.V.), which shall act as a proxy
 defined in Section 14 of version 3 of the license.
 
 This program is distributed in the hope that it will be useful,
@@ -82,8 +82,9 @@ int XliffStorage::load(QIODevice* device)
 
 
     QDomElement file=m_doc.elementsByTagName("file").at(0).toElement();
-    m_langCode=file.attribute("target-language");
-    m_numberOfPluralForms=numberOfPluralFormsForLangCode(m_langCode);
+    m_sourceLangCode=file.attribute("source-language");
+    m_targetLangCode=file.attribute("target-language");
+    m_numberOfPluralForms=numberOfPluralFormsForLangCode(m_targetLangCode);
 
     //Create entry mapping.
     //Along the way: for langs with more than 2 forms
@@ -136,10 +137,10 @@ int XliffStorage::load(QIODevice* device)
 //             while (msgstr.count()<m_numberOfPluralForms)
 //                 msgstr.append(QString());
 //             item.setMsgstr(msgstr);
-// 
+//
 //         }
 //         ++i;
-// 
+//
 //     }
 
 
@@ -162,7 +163,7 @@ int XliffStorage::load(QIODevice* device)
     return 0;
 }
 
-bool XliffStorage::save(QIODevice* device)
+bool XliffStorage::save(QIODevice* device, bool belongsToProject)
 {
     QTextStream stream(device);
     m_doc.save(stream,2);
@@ -585,6 +586,8 @@ InlineTag XliffStorage::targetDeleteTag(const DocPosition& pos)
 
 void XliffStorage::setTarget(const DocPosition& pos, const QString& arg)
 {
+    Q_UNUSED(pos);
+    Q_UNUSED(arg);
 //TODO
 }
 
@@ -613,7 +616,7 @@ QVector<AltTrans> XliffStorage::altTrans(const DocPosition& pos) const
         };
         QString typeStr=elem.attribute("alttranstype");
         int i=-1;
-        while (++i<int(sizeof(types)) && types[i]!=typeStr)
+        while (++i<int(sizeof(types)/sizeof(char*)) && types[i]!=typeStr)
             ;
         aTrans.type=AltTrans::Type(i);
 
@@ -789,6 +792,7 @@ QVector<Note> XliffStorage::notes(const DocPosition& pos) const
 
 QVector<Note> XliffStorage::developerNotes(const DocPosition& pos) const
 {
+    Q_UNUSED(pos);
     //TODO
     return QVector<Note>();
 }
@@ -916,12 +920,14 @@ QString XliffStorage::phase(const DocPosition& pos) const
 
 QStringList XliffStorage::context(const DocPosition& pos) const
 {
+    Q_UNUSED(pos);
     //TODO
     return QStringList(QString());
 }
 
 QStringList XliffStorage::matchData(const DocPosition& pos) const
 {
+    Q_UNUSED(pos);
     return QStringList();
 }
 
