@@ -48,7 +48,7 @@ class GlossaryView: public QDockWidget
 
 public:
     GlossaryView(QWidget*,Catalog*,const QVector<KAction*>&);
-    virtual ~GlossaryView();
+    ~GlossaryView();
 
 
 //     void dragEnterEvent(QDragEnterEvent* event);
@@ -61,6 +61,9 @@ public slots:
 signals:
     void termInsertRequested(const QString&);
 
+private:
+    void clear();
+
 private:
     QScrollArea* m_browser;
     Catalog* m_catalog;
