@@ -1,12 +1,15 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2007-2008 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2011 by Nick Shaforostoff <shafff@ukr.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+  This program is free software; you can redistribute it and/or
+  modify it under the terms of the GNU General Public License as
+  published by the Free Software Foundation; either version 2 of
+  the License or (at your option) version 3 or any later version
+  accepted by the membership of KDE e.V. (or its successor approved
+  by the membership of KDE e.V.), which shall act as a proxy
+  defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,19 +17,7 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
-  In addition, as a special exception, the copyright holders give
-  permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
-  combinations including the two.  You must obey the GNU General
-  Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
-  your version of the file, but you are not obligated to do so.  If
-  you do not wish to do so, delete this exception statement from
-  your version.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **************************************************************************** */
 
@@ -43,11 +34,14 @@
 #include <kmessagebox.h>
 
 
+#include <QApplication>
 #include <QSplitter>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QSortFilterProxyModel>
 #include <QAbstractItemModel>
+#include <QStringListModel>
+#include <QShortcut>
 
 using namespace GlossaryNS;
 
@@ -67,10 +61,20 @@ GlossaryTreeView::GlossaryTreeView(QWidget *parent)
 
 }
 
-void GlossaryTreeView::currentChanged(const QModelIndex& current,const QModelIndex&/* previous*/)
+static QString modelIndexToId(const QModelIndex& item)
+{
+    return item.sibling(item.row(),0).data(Qt::DisplayRole).toString();
+}
+
+void GlossaryTreeView::currentChanged(const QModelIndex& current, const QModelIndex&/* previous*/)
 {
     if (current.isValid())
-        emit currentChanged(static_cast<QSortFilterProxyModel*>(model())->mapToSource(current).row());
+    {
+        //QModelIndex item=static_cast<QSortFilterProxyModel*>(model())->mapToSource(current);
+        //emit currentChanged(item.row());
+        emit currentChanged(modelIndexToId(current));
+        scrollTo(current);
+    }
 }
 
 void GlossaryTreeView::selectRow(int i)
@@ -87,7 +91,9 @@ void GlossaryTreeView::selectRow(int i)
 
 
 //BEGIN SubjectFieldModel
+//typedef QStringListModel SubjectFieldModel;
 
+#if 0
 class SubjectFieldModel: public QAbstractItemModel
 {
 public:
@@ -192,7 +198,7 @@ bool SubjectFieldModel::setItemData(const QModelIndex& index, const QMap<int,QVa
     }
     return true;
 }
-
+#endif
 //END SubjectFieldModel
 
 //BEGIN GlossaryWindow
@@ -200,19 +206,24 @@ bool SubjectFieldModel::setItemData(const QModelIndex& index, const QMap<int,QVa
 GlossaryWindow::GlossaryWindow(QWidget *parent)
  : KMainWindow(parent)
  , m_browser(new GlossaryTreeView(this))
- , m_proxyModel(new QSortFilterProxyModel(this))
+ , m_proxyModel(new GlossarySortFilterProxyModel(this))
  , m_reactOnSignals(true)
 {
-    setAttribute(Qt::WA_DeleteOnClose, true);
+    //setAttribute(Qt::WA_DeleteOnClose, true);
+    setAttribute(Qt::WA_DeleteOnClose, false);
 
     QSplitter* splitter=new QSplitter(Qt::Horizontal,this);
     setCentralWidget(splitter);
 
-    m_proxyModel->setFilterKeyColumn(GlossaryModel::English);
-    GlossaryModel* gloModel=new GlossaryModel(this);
-    m_proxyModel->setSourceModel(gloModel);
+    m_proxyModel->setFilterKeyColumn(-1);
+    m_proxyModel->setDynamicSortFilter(true);;
+    GlossaryModel* model=new GlossaryModel(this);
+    m_proxyModel->setSourceModel(model);
     m_browser->setModel(m_proxyModel);
-    //m_browser->setColumnWidth(GlossaryModel::ID, m_browser->columnWidth(GlossaryModel::ID)/2); //man this is  HACK y
+
+    m_browser->setUniformRowHeights(true);
+    m_browser->setAutoScroll(true);
+    m_browser->setColumnHidden(GlossaryModel::ID,true);
     m_browser->setColumnWidth(GlossaryModel::English, m_browser->columnWidth(GlossaryModel::English)*2); //man this is  HACK y
     m_browser->setColumnWidth(GlossaryModel::Target, m_browser->columnWidth(GlossaryModel::Target)*2);
     m_browser->setAlternatingRowColors(true);
@@ -220,84 +231,92 @@ GlossaryWindow::GlossaryWindow(QWidget *parent)
     //left
     QWidget* w=new QWidget(splitter);
     QVBoxLayout* layout=new QVBoxLayout(w);
-    m_lineEdit=new KLineEdit(w);
-    m_lineEdit->setClearButtonShown(true);
-    m_lineEdit->setFocus();
+    m_filterEdit=new KLineEdit(w);
+    m_filterEdit->setClearButtonShown(true);
+    m_filterEdit->setClickMessage(i18n("Quick search..."));
+    m_filterEdit->setFocus();
+    new QShortcut(Qt::CTRL+Qt::Key_L,m_filterEdit,SLOT(setFocus()),0,Qt::WidgetWithChildrenShortcut);
+
 //     connect (m_lineEdit,SIGNAL(textChanged(QString)),
 //              m_proxyModel,SLOT(setFilterFixedString(QString)));
-    connect (m_lineEdit,SIGNAL(textChanged(QString)),
+    connect (m_filterEdit,SIGNAL(textChanged(QString)),
              m_proxyModel,SLOT(setFilterRegExp(QString)));
 
-    layout->addWidget(m_lineEdit);
+    layout->addWidget(m_filterEdit);
     layout->addWidget(m_browser);
     {
         KPushButton* addBtn=new KPushButton(KStandardGuiItem::add(),w);
-        connect(addBtn,SIGNAL(clicked()),
-                this,SLOT(newTerm()));
+        connect(addBtn,SIGNAL(clicked()),       this,SLOT(newTerm()));
 
         KPushButton* rmBtn=new KPushButton(KStandardGuiItem::remove(),w);
-        connect(rmBtn,SIGNAL(clicked()),
-                this,SLOT(rmTerm()));
+        connect(rmBtn,SIGNAL(clicked()),        this,SLOT(rmTerm()));
 
         KPushButton* restoreBtn=new KPushButton(i18nc("@action:button reloads glossary from disk","Restore"),w);
         restoreBtn->setToolTip(i18nc("@info:tooltip","Reload glossary from disk, discarding any changes"));
-        connect(restoreBtn,SIGNAL(clicked()),
-                this,SLOT(restore()));
+        connect(restoreBtn,SIGNAL(clicked()),   this,SLOT(restore()));
 
         QWidget* btns=new QWidget(w);
         QHBoxLayout* btnsLayout=new QHBoxLayout(btns);
         btnsLayout->addWidget(addBtn);
         btnsLayout->addWidget(rmBtn);
         btnsLayout->addWidget(restoreBtn);
-        btns->setLayout(btnsLayout);
 
         layout->addWidget(btns);
         //QWidget::setTabOrder(m_browser,addBtn);
         QWidget::setTabOrder(addBtn,rmBtn);
         QWidget::setTabOrder(rmBtn,restoreBtn);
-        QWidget::setTabOrder(restoreBtn,m_lineEdit);
+        QWidget::setTabOrder(restoreBtn,m_filterEdit);
     }
-    QWidget::setTabOrder(m_lineEdit,m_browser);
+    QWidget::setTabOrder(m_filterEdit,m_browser);
 
-    w->setLayout(layout);
     splitter->addWidget(w);
 
     //right
-    w=new QWidget(splitter);
-    m_editor=w;
-    w->hide();
+    m_editor=new QWidget(splitter);
+    m_editor->hide();
     Ui_TermEdit ui_termEdit;
-    ui_termEdit.setupUi(w);
-    splitter->addWidget(w);
+    ui_termEdit.setupUi(m_editor);
+    splitter->addWidget(m_editor);
 
-    m_english=ui_termEdit.english;
-    m_target=ui_termEdit.target;
+
+    Project* project=Project::instance();
+    m_sourceTermsModel=new TermsListModel(project->glossary(), project->sourceLangCode(), this);
+    m_targetTermsModel=new TermsListModel(project->glossary(), project->targetLangCode(), this);
+
+    ui_termEdit.sourceTermsView->setModel(m_sourceTermsModel);
+    ui_termEdit.targetTermsView->setModel(m_targetTermsModel);
+
+    m_sourceTermsView=ui_termEdit.sourceTermsView;
+    m_targetTermsView=ui_termEdit.targetTermsView;
     m_subjectField=ui_termEdit.subjectField;
     m_definition=ui_termEdit.definition;
 
-    connect (m_english,SIGNAL(textChanged()),
-             this,SLOT(chTerm()));
-    connect (m_target,SIGNAL(textChanged()),
-             this,SLOT(chTerm()));
-    connect (m_definition,SIGNAL(textChanged()),
-             this,SLOT(chTerm()));
-    connect (m_subjectField,SIGNAL(editTextChanged(QString)),
-             this,SLOT(chTerm()));
+    //connect (m_english,SIGNAL(textChanged()),   this,SLOT(applyEntryChange()));
+    //connect (m_target,SIGNAL(textChanged()),    this,SLOT(applyEntryChange()));
+    //connect (m_definition,SIGNAL(editingFinished()),this,SLOT(applyEntryChange()));
+    //connect (m_definition,SIGNAL(textChanged()),this,SLOT(applyEntryChange()));
+    //connect (m_subjectField,SIGNAL(editTextChanged(QString)),this,SLOT(applyEntryChange()));
+    connect (m_subjectField->lineEdit(),SIGNAL(editingFinished()),this,SLOT(applyEntryChange()));
 
 
-    //m_subjectField->addItems(Project::instance()->glossary()->subjectFields);
-    m_subjectField->setModel(new SubjectFieldModel(this));
-    connect(m_browser,SIGNAL(currentChanged(int)),
-            this,SLOT(currentChanged(int)));
-    connect(m_browser,SIGNAL(clicked(QModelIndex)),
-            m_english,SLOT(setFocus()));
+    //m_subjectField->addItems(Project::instance()->glossary()->subjectFields());
+    //m_subjectField->setModel(new SubjectFieldModel(this));
+    QStringList subjectFields=Project::instance()->glossary()->subjectFields();
+    qSort(subjectFields);
+    QStringListModel* subjectFieldsModel=new QStringListModel(this);
+    subjectFieldsModel->setStringList(subjectFields);
+    m_subjectField->setModel(subjectFieldsModel);
+    connect(m_browser,SIGNAL(currentChanged(int)), this,SLOT(currentChanged(int)));
+    connect(m_browser,SIGNAL(currentChanged(QString)), this,SLOT(showEntryInEditor(QString)));
 
+    //TODO
+    //connect(m_targetTermsModel,SIGNAL(dataChanged(QModelIndex,QModelIndex)),m_browser,SLOT(setFocus()));
 
     setAutoSaveSettings(QLatin1String("GlossaryWindow"),true);
-    Glossary* glo=Project::instance()->glossary();
-    setCaption(i18nc("@title:window","Glossary"),
-              !glo->changedIds.isEmpty()||!glo->addedIds.isEmpty()||!glo->removedIds.isEmpty());
-//    QTimer::singleShot(0,this,SLOT(initLater()));
+    //Glossary* glossary=Project::instance()->glossary();
+    /*setCaption(i18nc("@title:window","Glossary"),
+              !glossary->changedIds.isEmpty()||!glossary->addedIds.isEmpty()||!glossary->removedIds.isEmpty());
+              */
 }
 
 
@@ -305,90 +324,112 @@ GlossaryWindow::~GlossaryWindow()
 {
 }
 
+void GlossaryWindow::showEntryInEditor(const QString& id)
+{
+    if (m_editor->isVisible())
+        applyEntryChange();
+    else
+        m_editor->show();
+
+    m_id=id;
+
+    m_reactOnSignals=false;
+
+    Project* project=Project::instance();
+    Glossary* glossary=project->glossary();
+    m_subjectField->setCurrentItem(glossary->subjectField(id),/*insert*/true);
+    m_definition->setPlainText(glossary->definition(id));
+
+
+    m_sourceTermsModel->setEntry(id);
+    m_targetTermsModel->setEntry(id);
+
+    //m_sourceTermsModel->setStringList(glossary->terms(id,project->sourceLangCode()));
+    //m_targetTermsModel->setStringList(glossary->terms(id,project->targetLangCode()));
+
+    m_reactOnSignals=true;
+}
+
 void GlossaryWindow::currentChanged(int i)
 {
+    Q_UNUSED(i);
 //    kDebug()<<"start"<<i;
     m_reactOnSignals=false;
 
     m_editor->show();
-
+/*
     const TermEntry& a=Project::instance()->glossary()->termList.at(i);
     m_english->setPlainText(a.english.join("\n"));
     m_target->setPlainText(a.target.join("\n"));
     m_subjectField->setCurrentIndex(a.subjectField);
     m_definition->setPlainText(a.definition);
-
+*/
     m_reactOnSignals=true;
     //kDebug()<<"end";
 }
 
-void GlossaryWindow::chTerm()
+void GlossaryWindow::applyEntryChange()
 {
-    if (!m_reactOnSignals)
+    if (!m_reactOnSignals || !m_browser->currentIndex().isValid())
         return;
 
-    kDebug();
+    QString id=m_id;//modelIndexToId(m_browser->currentIndex());
+
+    Project* project=Project::instance();
+    Glossary* glossary=project->glossary();
+
+    if (m_subjectField->currentText()!=glossary->subjectField(id))
+        glossary->setSubjectField(id, m_subjectField->currentText());
+
+    if (m_definition->toPlainText()!=glossary->definition(id))
+        glossary->setDefinition(id, m_definition->toPlainText());
+
+    //HACK to force finishing of the listview editing
+    QWidget* prevFocusWidget=QApplication::focusWidget();
+    m_browser->setFocus();
+    if (prevFocusWidget)
+        prevFocusWidget->setFocus();
+
 //  QSortFilterProxyModel* proxyModel=static_cast<QSortFilterProxyModel*>(model());
     //GlossaryModel* sourceModel=static_cast<GlossaryModel*>(m_proxyModel->sourceModel());
     const QModelIndex& idx=m_proxyModel->mapToSource( m_browser->currentIndex() );
     if (!idx.isValid())
         return;
-    setCaption(i18nc("@title:window","Glossary"),true);
-
-    int index=idx.row();
-    Glossary* glo=Project::instance()->glossary();
-    glo->unhashTermEntry(index);//we will rehash it after applying changes
-
-    QString id(glo->termList.at(index).id);
-    if (! (glo->changedIds.contains(id)||glo->addedIds.contains(id)) )
-    {
-        kDebug()<<"append";
-        glo->changedIds.append(id);
-    }
-
-    TermEntry& a=glo->termList[index];
-    a.english=m_english->toPlainText().split('\n');
-    a.target=m_target->toPlainText().split('\n');
-    a.definition=m_definition->toPlainText();
-    a.subjectField=glo->subjectFields.indexOf(m_subjectField->currentText());
-    if ((a.subjectField==-1) && !m_subjectField->currentText().isEmpty())
-    {
-        a.subjectField=glo->subjectFields.size();
-        glo->subjectFields.append(m_subjectField->currentText());
-    }
-
-    glo->hashTermEntry(index);
 
 
-    //update the GUI
-    const QModelIndex& parent=idx.parent();
-    int row=m_browser->currentIndex().row();
-    int i=m_proxyModel->columnCount();
-    while (--i>=0)
-        m_browser->update(m_proxyModel->index(row,i,parent));
-
-    kDebug()<<glo->changedIds;
-    glo->forceChangeSignal();
+    //TODO display filename, optionally stripped like for filetab names
+    setCaption(i18nc("@title:window","Glossary"),!glossary->isClean());
 }
 
 
+void GlossaryWindow::selectEntry(const QString& id)
+{
+    qApp->processEvents(); //let it fetch the rows
+
+    QModelIndexList items=m_proxyModel->match(m_proxyModel->index(0,0),Qt::DisplayRole,QVariant(id),1,0);
+    if (items.count())
+    {
+        m_browser->setCurrentIndex(items.first());
+        m_browser->scrollTo(items.first(),QAbstractItemView::PositionAtCenter);
+        //kDebug()<<id<<items<<items.first().row();
+    }
+    else
+    {
+        //the row is probably not fetched yet
+        m_browser->setCurrentIndex(QModelIndex());
+        showEntryInEditor(id);
+        //kDebug()<<id<<0;
+    }
+}
+
 void GlossaryWindow::newTerm(QString _english, QString _target)
 {
-//     kDebug()<<"start";
     setCaption(i18nc("@title:window","Glossary"),true);
 
-    const Glossary* glo=Project::instance()->glossary();
     GlossaryModel* sourceModel=static_cast<GlossaryModel*>(m_proxyModel->sourceModel());
-    if (sourceModel->appendRow(_english,_target))
-        m_browser->selectRow(glo->termList.size()-1);
-//     kDebug()<<"end";
-    m_english->setFocus();
-    kDebug()<<glo->addedIds;
-}
+    QString id=sourceModel->appendRow(_english,_target);
 
-void GlossaryWindow::selectTerm(int index)
-{
-    m_browser->selectRow(index);
+    selectEntry(id);
 }
 
 void GlossaryWindow::rmTerm(int i)
@@ -408,28 +449,28 @@ void GlossaryWindow::rmTerm(int i)
     }
 
     sourceModel->removeRow(i);
-    const Glossary* glo=Project::instance()->glossary();
-    kDebug()<<glo->removedIds;
 }
 
 void GlossaryWindow::restore()
 {
     setCaption(i18nc("@title:window","Glossary"),false);
 
-    Glossary* glo=Project::instance()->glossary();
-    glo->load(glo->path);
-    GlossaryModel* sourceModel=static_cast<GlossaryModel*>(m_proxyModel->sourceModel());
-    sourceModel->forceReset();
+    Glossary* glossary=Project::instance()->glossary();
+    glossary->load(glossary->path());
 }
 
+bool GlossaryWindow::save()
+{
+    //TODO add error message
+    return Project::instance()->glossary()->save();
+}
 
 bool GlossaryWindow::queryClose()
 {
-    Glossary* glo=Project::instance()->glossary();
+    Glossary* glossary=Project::instance()->glossary();
 
-    if (glo->changedIds.isEmpty()
-        &&glo->addedIds.isEmpty()
-        &&glo->removedIds.isEmpty())
+    applyEntryChange();
+    if (glossary->isClean())
         return true;
 
     switch(KMessageBox::warningYesNoCancel(this,
@@ -438,10 +479,9 @@ Do you want to save your changes or discard them?"),i18nc("@title:window","Warni
       KStandardGuiItem::save(),KStandardGuiItem::discard()))
     {
         case KMessageBox::Yes:
-            glo->save();
-            return true;
+            return save();
         case KMessageBox::No:
-            glo->load(glo->path);
+            glossary->load(glossary->path());
             return true;
         default:
             return false;
@@ -451,4 +491,20 @@ Do you want to save your changes or discard them?"),i18nc("@title:window","Warni
 
 //END GlossaryWindow
 
+void TermsListModel::setEntry(const QString& id)
+{
+    m_id=id;
+    QStringList terms=m_glossary->terms(m_id,m_lang);
+    terms.append(QString()); //allow adding new terms
+    setStringList(terms);
+}
+
+bool TermsListModel::setData(const QModelIndex& index, const QVariant& value, int role)
+{
+    Q_UNUSED(role);
+    m_glossary->setTerm(m_id,m_lang,index.row(),value.toString());
+    setEntry(m_id); //allow adding new terms
+    return true;
+}
+
 #include "glossarywindow.moc"
