@@ -1,5 +1,5 @@
 /*
-    This file is part of the Okteta Kasten module, part of the KDE project.
+    This file is part of the Okteta Kasten module, made within the KDE community.
 
     Copyright 2007-2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
@@ -69,12 +69,15 @@ StringsExtractView::StringsExtractView( StringsExtractTool *tool, QWidget* paren
     label->setBuddy( mMinLengthSpinBox );
     updateLayout->addWidget( mMinLengthSpinBox );
 
-    const KGuiItem updateGuiItem( i18nc("@action:button extract the strings from the byte array","&Extract"), "document-export",
-                      i18nc("@info:tooltip","Finds the strings contained in the selected range and lists them in the view below."),
-                      i18nc("@info:whatsthis",
-                            "If you press the <interface>Extract</interface> button, "
-                            "the selected range is searched for all strings which have the set minimum length. "
-                            "This strings found will be listed in the view below.") );
+    const KGuiItem updateGuiItem =
+        KGuiItem( i18nc("@action:button extract the strings from the byte array","&Extract"),
+                  QLatin1String("document-export"),
+                  i18nc("@info:tooltip",
+                        "Finds the strings contained in the selected range and lists them in the view below."),
+                  i18nc("@info:whatsthis",
+                        "If you press the <interface>Extract</interface> button, "
+                        "the selected range is searched for all strings which have the set minimum length. "
+                        "This strings found will be listed in the view below.") );
     mUpdateButton = new KPushButton( updateGuiItem, this );
     mUpdateButton->setEnabled( mTool->isApplyable() );
     connect( mUpdateButton, SIGNAL(clicked(bool)), mTool, SLOT(extractStrings()) );
@@ -109,7 +112,7 @@ StringsExtractView::StringsExtractView( StringsExtractTool *tool, QWidget* paren
 
     mContainedStringTableView = new QTreeView( this );
     connect( KGlobalSettings::self(), SIGNAL(kdisplayFontChanged()),
-            SLOT(setFixedFontByGlobalSettings()) );
+             SLOT(setFixedFontByGlobalSettings()) );
     setFixedFontByGlobalSettings(); //do this before setting model
     mContainedStringTableView->setObjectName( QLatin1String( "ContainedStringTable" ) );
     mContainedStringTableView->setRootIsDecorated( false );
@@ -121,7 +124,7 @@ StringsExtractView::StringsExtractView( StringsExtractTool *tool, QWidget* paren
     mContainedStringTableView->installEventFilter( this );
     QHeaderView* header = mContainedStringTableView->header();
     header->setFont( font() );
-    header->setResizeMode( QHeaderView::ResizeToContents );
+    header->setResizeMode( QHeaderView::Interactive );
     mContainedStringTableView->setModel( mSortFilterProxyModel );
     mContainedStringTableView->sortByColumn( ContainedStringTableModel::OffsetColumnId, Qt::AscendingOrder );
     connect( mContainedStringTableView, SIGNAL(doubleClicked( const QModelIndex& )),
@@ -135,22 +138,28 @@ StringsExtractView::StringsExtractView( StringsExtractTool *tool, QWidget* paren
     // actions
     QHBoxLayout *actionsLayout = new QHBoxLayout();
 
-    const KGuiItem copyGuiItem( i18n("C&opy"), "edit-copy",
-                      i18nc("@info:tooltip","Copies the selected strings to the clipboard."),
-                      i18nc("@info:whatsthis",
-                            "If you press the <interface>Copy</interface> button, all strings you selected "
-                            "in the list are copied to the clipboard.") );
+    const KGuiItem copyGuiItem =
+        KGuiItem( i18n("C&opy"),
+                  QLatin1String("edit-copy"),
+                  i18nc("@info:tooltip",
+                        "Copies the selected strings to the clipboard."),
+                  i18nc("@info:whatsthis",
+                        "If you press the <interface>Copy</interface> button, all strings you selected "
+                        "in the list are copied to the clipboard.") );
     mCopyButton = new KPushButton( copyGuiItem, this );
     connect( mCopyButton, SIGNAL(clicked(bool)), SLOT(onCopyButtonClicked()) );
     actionsLayout->addWidget( mCopyButton );
 
     actionsLayout->addStretch();
 
-    const KGuiItem gotoGuiItem( i18n("&Show"), "go-jump",
-                      i18nc("@info:tooltip","Shows the selected string in the view."),
-                      i18nc("@info:whatsthis",
-                            "If you press the <interface>Go to</interface> button, the string which was last "
-                            "selected is marked and shown in the view.") );
+    const KGuiItem gotoGuiItem =
+        KGuiItem( i18n("&Show"),
+                  QLatin1String("go-jump"),
+                  i18nc("@info:tooltip",
+                        "Shows the selected string in the view."),
+                  i18nc("@info:whatsthis",
+                        "If you press the <interface>Go to</interface> button, the string which was last "
+                        "selected is marked and shown in the view.") );
     mGotoButton = new KPushButton( gotoGuiItem, this );
     connect( mGotoButton, SIGNAL(clicked(bool)), SLOT(onGotoButtonClicked()) );
     actionsLayout->addWidget( mGotoButton );
@@ -164,13 +173,6 @@ StringsExtractView::StringsExtractView( StringsExtractTool *tool, QWidget* paren
     onStringSelectionChanged();
 }
 
-#if 0
-void StringsExtractView::setDirty( bool dirty )
-{
-    mUpdateButton->setToolTip( dirty ? i18nc("@info:tooltip","Warning: Byte Array has been modified since last update.") : QString() );
-}
-#endif
-
 bool StringsExtractView::eventFilter( QObject* object, QEvent* event )
 {
     if( object == mContainedStringTableView )
@@ -234,7 +236,8 @@ void StringsExtractView::onCopyButtonClicked()
     foreach( const QModelIndex &index, selectedRows )
     {
         const int i = mSortFilterProxyModel->mapToSource(index).row();
-        strings += ( containedStringList->at( i ).string() + '\n' ); //TODO: specific linefeed for platforms
+        strings += containedStringList->at( i ).string();
+        strings += QLatin1Char('\n'); //TODO: specific linefeed for platforms
     }
     QApplication::clipboard()->setText( strings );
 }
