@@ -4,18 +4,14 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2010                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 #include "classifier.h"
 
-// kde includes
-#include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-
 // app includes
 #include "association.h"
+#include "debug_utils.h"
 #include "umlassociationlist.h"
 #include "operation.h"
 #include "attribute.h"
@@ -37,6 +33,10 @@
 #include "optionstate.h"
 #include "icon_utils.h"
 
+// kde includes
+#include <klocale.h>
+#include <kmessagebox.h>
+
 // qt includes
 #include <QtCore/QPointer>
 
@@ -632,7 +632,7 @@ UMLClassifierList UMLClassifier::findSuperClassConcepts (ClassifierType type)
 /**
  * Overloaded '==' operator.
  */
-bool UMLClassifier::operator==(const UMLClassifier & rhs )
+bool UMLClassifier::operator==(const UMLClassifier & rhs) const
 {
   /*
     if ( m_List.count() != rhs.m_List.count() ) {
@@ -801,7 +801,7 @@ UMLAttribute* UMLClassifier::addAttribute(const QString &name, Uml::IDType id /*
         if (obj->baseType() == Uml::ot_Attribute && obj->name() == name)
             return static_cast<UMLAttribute*>(obj);
     }
-    Uml::Visibility scope = Settings::getOptionState().classState.defaultAttributeScope;
+    Uml::Visibility scope = Settings::optionState().classState.defaultAttributeScope;
     UMLAttribute *a = new UMLAttribute(this, name, id, scope);
     m_List.append(a);
     emit attributeAdded(a);
