@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2010                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -22,7 +22,7 @@ namespace Uml
     CmdRenameUMLObject::CmdRenameUMLObject(UMLObject* o, const QString& name)
       : m_obj(o), m_name(name)
     {
-        setText(i18n("Rename object"));
+        setText(i18n("Rename object : %1 to %2", o->name(), name));
         m_oldname = o->name();
     }
 
