@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -31,7 +31,7 @@ namespace Uml
     CmdChangeLineColor::CmdChangeLineColor(UMLWidget *w, const QColor& col)
       : m_umlWidget(w), m_newColor(col)
     {
-        setText(i18n("Change Line Color") + w->name());
+        setText(i18n("Change line color : %1", w->name()));
         m_oldColor= w->lineColor() ;
     }
 
