@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2010                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -23,7 +23,7 @@ namespace Uml
     CmdChangeMulti::CmdChangeMulti(UMLRole *role, const QString &multi)
       : m_umlRole(role), m_newMulti(multi)
     {
-        setText(i18n("Change Multiplicity"));
+        setText(i18n("Change multiplicity : %1 to %2", role->name(), multi));
         m_oldMulti = m_umlRole->multiplicity();
     }
 
