@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2010                                               *
+ *   copyright (C) 2004-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -16,15 +16,13 @@
 #include "association.h"
 #include "attribute.h"
 #include "classifiercodedocument.h"
+#include "debug_utils.h"
 #include "umldoc.h"
 #include "umlobject.h"
 #include "umlrole.h"
 #include "uml.h"
 #include "codegenfactory.h"
 
-// kde includes
-#include <kdebug.h>
-
 // Constructor
 CodeParameter::CodeParameter ( ClassifierCodeDocument * parentDoc, UMLObject * parentObject )
         : QObject ( parentObject)
