@@ -344,7 +344,7 @@ void JavaClassifierCodeDocument::updateContent( )
     //
     QString pkgs = getPackage();
     pkgs.replace(QRegExp("::"), ".");
-    QString packageText = getPackage().isEmpty() ? "" : "package "+pkgs+';'+endLine;
+    QString packageText = getPackage().isEmpty() ? "" : QString(QLatin1String("package ")+pkgs+QLatin1Char(';')+endLine);
     CodeBlockWithComments * pblock = addOrUpdateTaggedCodeBlockWithComments("packages", packageText, "", 0, false);
     if(packageText.isEmpty() && pblock->getContentType() == CodeBlock::AutoGenerated)
         pblock->setWriteOutText(false);
