@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2010                                               *
+ *   copyright (C) 2004-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -15,15 +15,13 @@
 // local includes
 #include "association.h"
 #include "classifier.h"
+#include "debug_utils.h"
 #include "umldoc.h"
 #include "umlobject.h"
 #include "umlrole.h"
 #include "uml.h"
 #include "textblock.h"
 
-// kde includes
-#include <kdebug.h>
-
 OwnedCodeBlock::OwnedCodeBlock ( UMLObject * parent )
     : QObject ( parent )
 {
