@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2006-2009                                                *
+ *  copyright (C) 2006-2010                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
@@ -35,7 +35,7 @@
 void ClassImport::importFiles(const QStringList &fileList)
 {
     initialize();
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    UMLDoc *umldoc = UMLApp::app()->document();
     uint processedFilesCount = 0;
     for (QStringList::const_iterator fileIT = fileList.begin();
             fileIT != fileList.end(); ++fileIT) {
