@@ -68,44 +68,44 @@ void SettingsDlg::setupUIPage()
 
     m_UiWidgets.colorGB = new QGroupBox( i18nc("color group box", "Color"), page );
     QGridLayout * colorLayout = new QGridLayout( m_UiWidgets.colorGB );
-    colorLayout -> setSpacing( spacingHint() );
-    colorLayout -> setMargin( fontMetrics().height() );
+    colorLayout->setSpacing( spacingHint() );
+    colorLayout->setMargin( fontMetrics().height() );
 
     m_UiWidgets.lineColorL = new QLabel( i18n("Line color:"), m_UiWidgets.colorGB );
-    colorLayout -> addWidget( m_UiWidgets.lineColorL, 0, 0 );
+    colorLayout->addWidget( m_UiWidgets.lineColorL, 0, 0 );
 
     m_UiWidgets.lineColorB = new KColorButton( m_pOptionState->uiState.lineColor ,m_UiWidgets.colorGB);
     //m_UiWidgets.lineColorB->setObjectName( m_UiWidgets.colorGB );
-    colorLayout -> addWidget( m_UiWidgets.lineColorB, 0, 1 );
+    colorLayout->addWidget( m_UiWidgets.lineColorB, 0, 1 );
 
     m_UiWidgets.lineDefaultB = new QPushButton( i18n("D&efault Color"), m_UiWidgets.colorGB );
-    colorLayout -> addWidget( m_UiWidgets.lineDefaultB, 0, 2 );
+    colorLayout->addWidget( m_UiWidgets.lineDefaultB, 0, 2 );
 
     m_UiWidgets.fillColorL = new QLabel( i18n("Fill color:"), m_UiWidgets.colorGB );
-    colorLayout -> addWidget( m_UiWidgets.fillColorL, 1, 0 );
+    colorLayout->addWidget( m_UiWidgets.fillColorL, 1, 0 );
 
     m_UiWidgets.fillColorB = new KColorButton( m_pOptionState->uiState.fillColor,m_UiWidgets.colorGB  );
     //m_UiWidgets.fillColorB->setObjectName( m_UiWidgets.colorGB );
-    colorLayout -> addWidget( m_UiWidgets.fillColorB, 1, 1 );
+    colorLayout->addWidget( m_UiWidgets.fillColorB, 1, 1 );
 
     m_UiWidgets.fillDefaultB = new QPushButton( i18n("De&fault Color"), m_UiWidgets.colorGB );
-    colorLayout -> addWidget( m_UiWidgets.fillDefaultB, 1, 2 );
+    colorLayout->addWidget( m_UiWidgets.fillDefaultB, 1, 2 );
 
     m_UiWidgets.lineWidthL = new QLabel( i18n("Line width:"), m_UiWidgets.colorGB );
-    colorLayout -> addWidget( m_UiWidgets.lineWidthL, 2, 0 );
+    colorLayout->addWidget( m_UiWidgets.lineWidthL, 2, 0 );
 
     // Low-Limit: 0, High-Limit: 10, Step: 1, Initial-Val: m_pOptionState->uiState.lineWidth
     // Number-Base: 10 ( decimal ), Parent: m_UiWidgets.colorGB
     m_UiWidgets.lineWidthB = new KIntSpinBox( 0, 10, 1, m_pOptionState->uiState.lineWidth, m_UiWidgets.colorGB );
-    colorLayout -> addWidget( m_UiWidgets.lineWidthB, 2, 1 );
+    colorLayout->addWidget( m_UiWidgets.lineWidthB, 2, 1 );
 
     m_UiWidgets.lineWidthDefaultB = new QPushButton( i18n("D&efault Width"), m_UiWidgets.colorGB );
-    colorLayout -> addWidget( m_UiWidgets.lineWidthDefaultB, 2, 2 );
+    colorLayout->addWidget( m_UiWidgets.lineWidthDefaultB, 2, 2 );
 
     m_UiWidgets.useFillColorCB = new QCheckBox( i18n("&Use fill color"), m_UiWidgets.colorGB );
-    colorLayout -> setRowStretch( 3, 2 );
-    colorLayout -> addWidget( m_UiWidgets.useFillColorCB, 3, 0 );
-    m_UiWidgets.useFillColorCB -> setChecked( m_pOptionState->uiState.useFillColor );
+    colorLayout->setRowStretch( 3, 2 );
+    colorLayout->addWidget( m_UiWidgets.useFillColorCB, 3, 0 );
+    m_UiWidgets.useFillColorCB->setChecked( m_pOptionState->uiState.useFillColor );
 
     //connect button signals up
     connect( m_UiWidgets.lineDefaultB, SIGNAL(clicked()), this, SLOT(slotLineBClicked()) );
@@ -130,41 +130,41 @@ void SettingsDlg::setupGeneralPage()
 
     m_GeneralWidgets.undoCB = new QCheckBox( i18n("Enable undo"), m_GeneralWidgets.miscGB );
     m_GeneralWidgets.undoCB->setChecked( m_pOptionState->generalState.undo );
-    miscLayout -> addWidget( m_GeneralWidgets.undoCB, 0, 0 );
+    miscLayout->addWidget( m_GeneralWidgets.undoCB, 0, 0 );
 
     m_GeneralWidgets.tabdiagramsCB = new QCheckBox( i18n("Use tabbed diagrams"), m_GeneralWidgets.miscGB );
-    m_GeneralWidgets.tabdiagramsCB -> setChecked( m_pOptionState->generalState.tabdiagrams );
-    miscLayout -> addWidget( m_GeneralWidgets.tabdiagramsCB, 0, 1 );
+    m_GeneralWidgets.tabdiagramsCB->setChecked( m_pOptionState->generalState.tabdiagrams );
+    miscLayout->addWidget( m_GeneralWidgets.tabdiagramsCB, 0, 1 );
 
     m_GeneralWidgets.newcodegenCB = new QCheckBox( i18n("Use new C++/Java/Ruby generators"), m_GeneralWidgets.miscGB );
-    m_GeneralWidgets.newcodegenCB -> setChecked( m_pOptionState->generalState.newcodegen );
-    miscLayout -> addWidget( m_GeneralWidgets.newcodegenCB, 1, 0 );
+    m_GeneralWidgets.newcodegenCB->setChecked( m_pOptionState->generalState.newcodegen );
+    miscLayout->addWidget( m_GeneralWidgets.newcodegenCB, 1, 0 );
 
     m_GeneralWidgets.angularLinesCB = new QCheckBox( i18n("Use angular association lines"), m_GeneralWidgets.miscGB );
-    m_GeneralWidgets.angularLinesCB -> setChecked( m_pOptionState->generalState.angularlines );
-    miscLayout -> addWidget( m_GeneralWidgets.angularLinesCB, 1, 1 );
+    m_GeneralWidgets.angularLinesCB->setChecked( m_pOptionState->generalState.angularlines );
+    miscLayout->addWidget( m_GeneralWidgets.angularLinesCB, 1, 1 );
 
     m_GeneralWidgets.footerPrintingCB = new QCheckBox( i18n("Turn on footer and page numbers when printing"), m_GeneralWidgets.miscGB );
-    m_GeneralWidgets.footerPrintingCB -> setChecked( m_pOptionState->generalState.footerPrinting );
-    miscLayout -> addWidget( m_GeneralWidgets.footerPrintingCB, 2, 0 );
+    m_GeneralWidgets.footerPrintingCB->setChecked( m_pOptionState->generalState.footerPrinting );
+    miscLayout->addWidget( m_GeneralWidgets.footerPrintingCB, 2, 0 );
 
     //setup autosave settings
     m_GeneralWidgets.autosaveGB = new QGroupBox( i18n("Autosave"), page );
 
     QGridLayout * autosaveLayout = new QGridLayout( m_GeneralWidgets.autosaveGB );
-    autosaveLayout -> setSpacing( spacingHint() );
-    autosaveLayout -> setMargin( fontMetrics().height() );
+    autosaveLayout->setSpacing( spacingHint() );
+    autosaveLayout->setMargin( fontMetrics().height() );
 
     m_GeneralWidgets.autosaveCB = new QCheckBox( i18n("E&nable autosave"), m_GeneralWidgets.autosaveGB );
-    m_GeneralWidgets.autosaveCB -> setChecked( m_pOptionState->generalState.autosave );
-    autosaveLayout -> addWidget( m_GeneralWidgets.autosaveCB, 0, 0 );
+    m_GeneralWidgets.autosaveCB->setChecked( m_pOptionState->generalState.autosave );
+    autosaveLayout->addWidget( m_GeneralWidgets.autosaveCB, 0, 0 );
 
     m_GeneralWidgets.autosaveL = new QLabel( i18n("Select auto-save time interval (mins):"), m_GeneralWidgets.autosaveGB );
-    autosaveLayout -> addWidget( m_GeneralWidgets.autosaveL, 1, 0 );
+    autosaveLayout->addWidget( m_GeneralWidgets.autosaveL, 1, 0 );
 
     m_GeneralWidgets.timeISB = new KIntSpinBox( 1, 600, 1, m_pOptionState->generalState.autosavetime, m_GeneralWidgets.autosaveGB );
-    m_GeneralWidgets.timeISB -> setEnabled( m_pOptionState->generalState.autosave );
-    autosaveLayout -> addWidget( m_GeneralWidgets.timeISB, 1, 1 );
+    m_GeneralWidgets.timeISB->setEnabled( m_pOptionState->generalState.autosave );
+    autosaveLayout->addWidget( m_GeneralWidgets.timeISB, 1, 1 );
 
     // Allow definition of Suffix for autosave ( default: ".xmi" )
     Dialog_Utils::makeLabeledEditField( m_GeneralWidgets.autosaveGB, autosaveLayout, 2,
@@ -183,24 +183,24 @@ void SettingsDlg::setupGeneralPage()
     m_GeneralWidgets.startupGB = new QGroupBox( i18n("Startup"), page );
 
     QGridLayout * startupLayout = new QGridLayout( m_GeneralWidgets.startupGB );
-    startupLayout -> setSpacing( spacingHint() );
-    startupLayout -> setMargin( fontMetrics().height() );
+    startupLayout->setSpacing( spacingHint() );
+    startupLayout->setMargin( fontMetrics().height() );
 
     m_GeneralWidgets.loadlastCB = new QCheckBox( i18n("&Load last project"), m_GeneralWidgets.startupGB );
-    m_GeneralWidgets.loadlastCB -> setChecked( m_pOptionState->generalState.loadlast );
-    startupLayout -> addWidget( m_GeneralWidgets.loadlastCB, 0, 0 );
+    m_GeneralWidgets.loadlastCB->setChecked( m_pOptionState->generalState.loadlast );
+    startupLayout->addWidget( m_GeneralWidgets.loadlastCB, 0, 0 );
 
     m_GeneralWidgets.startL = new QLabel( i18n("Start new project with:"), m_GeneralWidgets.startupGB );
-    startupLayout -> addWidget( m_GeneralWidgets.startL, 1, 0 );
+    startupLayout->addWidget( m_GeneralWidgets.startL, 1, 0 );
 
     m_GeneralWidgets.diagramKB = new KComboBox( m_GeneralWidgets.startupGB );
     m_GeneralWidgets.diagramKB->setCompletionMode( KGlobalSettings::CompletionPopup );
-    startupLayout -> addWidget( m_GeneralWidgets.diagramKB, 1, 1 );
+    startupLayout->addWidget( m_GeneralWidgets.diagramKB, 1, 1 );
 
     // start at 1 because we don't allow No Diagram any more
     // diagramNo 1 is Uml::dt_Class
     // digaramNo 9 is Uml::dt_EntityRelationship
-    for (int diagramNo=1; diagramNo < 10; diagramNo++) {
+    for (int diagramNo=1; diagramNo < 10; ++diagramNo) {
         insertDiagram( Model_Utils::diagramTypeToString( ( Uml::Diagram_Type )diagramNo ), /*index*/ diagramNo - 1  );
     }
 
@@ -208,11 +208,11 @@ void SettingsDlg::setupGeneralPage()
     connect( m_GeneralWidgets.autosaveCB, SIGNAL(clicked()), this, SLOT(slotAutosaveCBClicked()) );
 
     m_GeneralWidgets.defaultLanguageL = new QLabel( i18n( "Default Language :" ), m_GeneralWidgets.startupGB );
-    startupLayout -> addWidget( m_GeneralWidgets.defaultLanguageL, 2, 0 );
+    startupLayout->addWidget( m_GeneralWidgets.defaultLanguageL, 2, 0 );
 
     m_GeneralWidgets.languageKB = new KComboBox( m_GeneralWidgets.startupGB );
     m_GeneralWidgets.languageKB->setCompletionMode( KGlobalSettings::CompletionPopup );
-    startupLayout -> addWidget( m_GeneralWidgets.languageKB, 2, 1 );
+    startupLayout->addWidget( m_GeneralWidgets.languageKB, 2, 1 );
 
     int indexCounter = 0;
     while (indexCounter < Uml::pl_Reserved) {
@@ -244,48 +244,52 @@ void SettingsDlg::setupClassPage()
     m_ClassWidgets.visibilityGB = new QGroupBox( i18n("Visibility"), page );
 
     QGridLayout * visibilityLayout = new QGridLayout( m_ClassWidgets.visibilityGB );
-    visibilityLayout -> setSpacing( spacingHint() );
-    visibilityLayout -> setMargin(  fontMetrics().height()  );
+    visibilityLayout->setSpacing( spacingHint() );
+    visibilityLayout->setMargin(  fontMetrics().height()  );
 
     m_ClassWidgets.showVisibilityCB = new QCheckBox(i18n("Show &visibility"), m_ClassWidgets.visibilityGB);
-    m_ClassWidgets.showVisibilityCB -> setChecked(  m_pOptionState->classState.showVisibility );
-    visibilityLayout -> addWidget( m_ClassWidgets.showVisibilityCB, 0, 0 );
+    m_ClassWidgets.showVisibilityCB->setChecked(  m_pOptionState->classState.showVisibility );
+    visibilityLayout->addWidget( m_ClassWidgets.showVisibilityCB, 0, 0 );
 
     m_ClassWidgets.showAttsCB = new QCheckBox( i18n("Show attributes"), m_ClassWidgets.visibilityGB );
-    m_ClassWidgets.showAttsCB -> setChecked(  m_pOptionState->classState.showAtts );
-    visibilityLayout -> addWidget( m_ClassWidgets.showAttsCB, 0, 1 );
+    m_ClassWidgets.showAttsCB->setChecked(  m_pOptionState->classState.showAtts );
+    visibilityLayout->addWidget( m_ClassWidgets.showAttsCB, 0, 1 );
 
     m_ClassWidgets.showOpsCB = new QCheckBox( i18n("Show operations"), m_ClassWidgets.visibilityGB );
-    m_ClassWidgets.showOpsCB -> setChecked(  m_pOptionState->classState.showOps );
-    visibilityLayout -> addWidget( m_ClassWidgets.showOpsCB, 1, 0 );
+    m_ClassWidgets.showOpsCB->setChecked(  m_pOptionState->classState.showOps );
+    visibilityLayout->addWidget( m_ClassWidgets.showOpsCB, 1, 0 );
 
     m_ClassWidgets.showStereotypeCB = new QCheckBox( i18n("Show stereot&ype"), m_ClassWidgets.visibilityGB );
-    m_ClassWidgets.showStereotypeCB -> setChecked(  m_pOptionState->classState.showStereoType );
-    visibilityLayout -> addWidget( m_ClassWidgets.showStereotypeCB, 1, 1 );
+    m_ClassWidgets.showStereotypeCB->setChecked(  m_pOptionState->classState.showStereoType );
+    visibilityLayout->addWidget( m_ClassWidgets.showStereotypeCB, 1, 1 );
 
     m_ClassWidgets.showAttSigCB = new QCheckBox(i18n("Show attribute signature"), m_ClassWidgets.visibilityGB);
-    m_ClassWidgets.showAttSigCB -> setChecked(   m_pOptionState->classState.showAttSig );
-    visibilityLayout -> addWidget( m_ClassWidgets.showAttSigCB, 2, 0 );
+    m_ClassWidgets.showAttSigCB->setChecked(   m_pOptionState->classState.showAttSig );
+    visibilityLayout->addWidget( m_ClassWidgets.showAttSigCB, 2, 0 );
 
     m_ClassWidgets.showPackageCB = new QCheckBox(i18n("Show package"), m_ClassWidgets.visibilityGB);
-    m_ClassWidgets.showPackageCB -> setChecked(  m_pOptionState->classState.showPackage );
-    visibilityLayout -> addWidget( m_ClassWidgets.showPackageCB, 2, 1 );
+    m_ClassWidgets.showPackageCB->setChecked(  m_pOptionState->classState.showPackage );
+    visibilityLayout->addWidget( m_ClassWidgets.showPackageCB, 2, 1 );
 
     m_ClassWidgets.showOpSigCB = new QCheckBox( i18n("Show operation signature"), m_ClassWidgets.visibilityGB );
-    m_ClassWidgets.showOpSigCB -> setChecked(  m_pOptionState->classState.showOpSig );
-    visibilityLayout -> addWidget( m_ClassWidgets.showOpSigCB, 3, 0 );
-    visibilityLayout -> setRowStretch( 3, 1 );
+    m_ClassWidgets.showOpSigCB->setChecked(  m_pOptionState->classState.showOpSig );
+    visibilityLayout->addWidget( m_ClassWidgets.showOpSigCB, 3, 0 );
+
+    m_ClassWidgets.showPublicOnlyCB = new QCheckBox( i18n("Show Public Only"), m_ClassWidgets.visibilityGB );
+    m_ClassWidgets.showPublicOnlyCB->setChecked(  m_pOptionState->classState.showPublicOnly );
+    visibilityLayout->addWidget( m_ClassWidgets.showPublicOnlyCB, 3, 1 );
+    visibilityLayout->setRowStretch( 3, 1 );
 
     m_ClassWidgets.scopeGB = new QGroupBox( i18n("Starting Scope"), page );
     QGridLayout * scopeLayout = new QGridLayout( m_ClassWidgets.scopeGB );
-    scopeLayout -> setSpacing( spacingHint() );
-    scopeLayout -> setMargin(  fontMetrics().height()  );
+    scopeLayout->setSpacing( spacingHint() );
+    scopeLayout->setMargin(  fontMetrics().height()  );
 
     m_ClassWidgets.attributeLabel = new QLabel( i18n("Default attribute scope:"), m_ClassWidgets.scopeGB);
-    scopeLayout -> addWidget( m_ClassWidgets.attributeLabel, 0, 0 );
+    scopeLayout->addWidget( m_ClassWidgets.attributeLabel, 0, 0 );
 
     m_ClassWidgets.operationLabel = new QLabel( i18n("Default operation scope:"), m_ClassWidgets.scopeGB);
-    scopeLayout -> addWidget( m_ClassWidgets.operationLabel, 1, 0 );
+    scopeLayout->addWidget( m_ClassWidgets.operationLabel, 1, 0 );
 
     m_ClassWidgets.m_pAttribScopeCB = new KComboBox(m_ClassWidgets.scopeGB);
     insertAttribScope( tr2i18n( "Public" ) );
@@ -293,7 +297,7 @@ void SettingsDlg::setupClassPage()
     insertAttribScope( tr2i18n( "Protected" ) );
     m_ClassWidgets.m_pAttribScopeCB->setCurrentIndex(m_pOptionState->classState.defaultAttributeScope);
     m_ClassWidgets.m_pAttribScopeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
-    scopeLayout -> addWidget( m_ClassWidgets.m_pAttribScopeCB, 0, 1 );
+    scopeLayout->addWidget( m_ClassWidgets.m_pAttribScopeCB, 0, 1 );
 
     m_ClassWidgets.m_pOperationScopeCB = new KComboBox(m_ClassWidgets.scopeGB);
     insertOperationScope( tr2i18n( "Public" ) );
@@ -301,7 +305,7 @@ void SettingsDlg::setupClassPage()
     insertOperationScope( tr2i18n( "Protected" ) );
     m_ClassWidgets.m_pOperationScopeCB->setCurrentIndex(m_pOptionState->classState.defaultOperationScope);
     m_ClassWidgets.m_pOperationScopeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
-    scopeLayout -> addWidget( m_ClassWidgets.m_pOperationScopeCB, 1, 1 );
+    scopeLayout->addWidget( m_ClassWidgets.m_pOperationScopeCB, 1, 1 );
 }
 
 /**
@@ -352,14 +356,14 @@ void SettingsDlg::setupFontPage()
     pageFont->setHeader( i18n("Font Settings") );
     pageFont->setIcon( Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_Font) );
     addPage( pageFont );
-    m_FontWidgets.chooser = new KFontChooser( page,  false, QStringList(), false);
+    m_FontWidgets.chooser = new KFontChooser( page,  KFontChooser::NoDisplayFlags, QStringList(), 0);
     m_FontWidgets.chooser->setFont( m_pOptionState->uiState.font );
 }
 
 void SettingsDlg::slotApply()
 {
     applyPage( currentPage() );
-    //do no emit signal applyClicked in the slot slotApply -> infinite loop
+    //do no emit signal applyClicked in the slot slotApply->infinite loop
     //emit applyClicked();
 }
 
@@ -381,33 +385,33 @@ void SettingsDlg::slotDefault()
     KPageWidgetItem *current = currentPage();
     if ( current ==  pageGeneral )
     {
-        m_GeneralWidgets.autosaveCB -> setChecked( false );
-        m_GeneralWidgets.timeISB -> setValue( 5 );
+        m_GeneralWidgets.autosaveCB->setChecked( false );
+        m_GeneralWidgets.timeISB->setValue( 5 );
         m_GeneralWidgets.timeISB->setEnabled( true );
-        m_GeneralWidgets.loadlastCB -> setChecked( true );
-        m_GeneralWidgets.diagramKB -> setCurrentIndex( 0 );
+        m_GeneralWidgets.loadlastCB->setChecked( true );
+        m_GeneralWidgets.diagramKB->setCurrentIndex( 0 );
         m_GeneralWidgets.languageKB->setCurrentIndex( ( int )Model_Utils::stringToProgLang( "C++" ) );
     }
     else if ( current == pageFont )
     {
-        m_FontWidgets.chooser -> setFont( parentWidget() -> font() );
+        m_FontWidgets.chooser->setFont( parentWidget()->font() );
     }
     else if ( current == pageUserInterface )
     {
-        m_UiWidgets.useFillColorCB -> setChecked( true );
-        m_UiWidgets.fillColorB -> setColor( QColor( 255, 255, 192 ) );
-        m_UiWidgets.lineColorB -> setColor( Qt::red );
-        m_UiWidgets.lineWidthB -> setValue( 0 );
+        m_UiWidgets.useFillColorCB->setChecked( true );
+        m_UiWidgets.fillColorB->setColor( QColor( 255, 255, 192 ) );
+        m_UiWidgets.lineColorB->setColor( Qt::red );
+        m_UiWidgets.lineWidthB->setValue( 0 );
     }
     else if ( current == pageClass )
     {
-        m_ClassWidgets.showVisibilityCB -> setChecked( false );
-        m_ClassWidgets.showAttsCB -> setChecked( true );
-        m_ClassWidgets.showOpsCB -> setChecked( true );
-        m_ClassWidgets.showStereotypeCB -> setChecked( false );
-        m_ClassWidgets.showAttSigCB -> setChecked( false );
-        m_ClassWidgets.showOpSigCB -> setChecked( false );
-        m_ClassWidgets.showPackageCB -> setChecked( false );
+        m_ClassWidgets.showVisibilityCB->setChecked( false );
+        m_ClassWidgets.showAttsCB->setChecked( true );
+        m_ClassWidgets.showOpsCB->setChecked( true );
+        m_ClassWidgets.showStereotypeCB->setChecked( false );
+        m_ClassWidgets.showAttSigCB->setChecked( false );
+        m_ClassWidgets.showOpSigCB->setChecked( false );
+        m_ClassWidgets.showPackageCB->setChecked( false );
         m_ClassWidgets.m_pAttribScopeCB->setCurrentIndex(1); // Private
         m_ClassWidgets.m_pOperationScopeCB->setCurrentIndex(0); // Public
     }
@@ -421,39 +425,39 @@ void SettingsDlg::applyPage( KPageWidgetItem*item )
     m_bChangesApplied = true;
     if ( item == pageGeneral )
     {
-        m_pOptionState->generalState.undo = m_GeneralWidgets.undoCB -> isChecked();
+        m_pOptionState->generalState.undo = m_GeneralWidgets.undoCB->isChecked();
         m_pOptionState->generalState.tabdiagrams = m_GeneralWidgets.tabdiagramsCB->isChecked();
         m_pOptionState->generalState.newcodegen = m_GeneralWidgets.newcodegenCB->isChecked();
         m_pOptionState->generalState.angularlines = m_GeneralWidgets.angularLinesCB->isChecked();
         m_pOptionState->generalState.footerPrinting = m_GeneralWidgets.footerPrintingCB->isChecked();
-        m_pOptionState->generalState.autosave = m_GeneralWidgets.autosaveCB -> isChecked();
-        m_pOptionState->generalState.autosavetime = m_GeneralWidgets.timeISB -> value();
+        m_pOptionState->generalState.autosave = m_GeneralWidgets.autosaveCB->isChecked();
+        m_pOptionState->generalState.autosavetime = m_GeneralWidgets.timeISB->value();
         // retrieve Suffix setting from dialog entry
-        m_pOptionState->generalState.autosavesuffix = m_GeneralWidgets.autosaveSuffixT -> text();
-        m_pOptionState->generalState.loadlast = m_GeneralWidgets.loadlastCB -> isChecked();
+        m_pOptionState->generalState.autosavesuffix = m_GeneralWidgets.autosaveSuffixT->text();
+        m_pOptionState->generalState.loadlast = m_GeneralWidgets.loadlastCB->isChecked();
         m_pOptionState->generalState.diagram  = (Uml::Diagram_Type)(m_GeneralWidgets.diagramKB->currentIndex() + 1);
         m_pOptionState->generalState.defaultLanguage = ( Uml::Programming_Language )( m_GeneralWidgets.languageKB->currentIndex()  );
     }
     else if ( item == pageFont )
     {
-        m_pOptionState->uiState.font = m_FontWidgets.chooser -> font();
+        m_pOptionState->uiState.font = m_FontWidgets.chooser->font();
     }
     else if ( item == pageUserInterface )
     {
-        m_pOptionState->uiState.useFillColor = m_UiWidgets.useFillColorCB -> isChecked();
-        m_pOptionState->uiState.fillColor = m_UiWidgets.fillColorB -> color();
-        m_pOptionState->uiState.lineColor = m_UiWidgets.lineColorB -> color();
-        m_pOptionState->uiState.lineWidth = m_UiWidgets.lineWidthB -> value();
+        m_pOptionState->uiState.useFillColor = m_UiWidgets.useFillColorCB->isChecked();
+        m_pOptionState->uiState.fillColor = m_UiWidgets.fillColorB->color();
+        m_pOptionState->uiState.lineColor = m_UiWidgets.lineColorB->color();
+        m_pOptionState->uiState.lineWidth = m_UiWidgets.lineWidthB->value();
     }
     else if ( item == pageClass )
     {
-        m_pOptionState->classState.showVisibility = m_ClassWidgets.showVisibilityCB -> isChecked();
-        m_pOptionState->classState.showAtts = m_ClassWidgets.showAttsCB -> isChecked();
-        m_pOptionState->classState.showOps = m_ClassWidgets.showOpsCB -> isChecked();
-        m_pOptionState->classState.showStereoType = m_ClassWidgets.showStereotypeCB -> isChecked();
-        m_pOptionState->classState.showAttSig = m_ClassWidgets.showAttSigCB -> isChecked();
-        m_pOptionState->classState.showOpSig = m_ClassWidgets.showOpSigCB -> isChecked();
-        m_pOptionState->classState.showPackage = m_ClassWidgets.showPackageCB -> isChecked();
+        m_pOptionState->classState.showVisibility = m_ClassWidgets.showVisibilityCB->isChecked();
+        m_pOptionState->classState.showAtts = m_ClassWidgets.showAttsCB->isChecked();
+        m_pOptionState->classState.showOps = m_ClassWidgets.showOpsCB->isChecked();
+        m_pOptionState->classState.showStereoType = m_ClassWidgets.showStereotypeCB->isChecked();
+        m_pOptionState->classState.showAttSig = m_ClassWidgets.showAttSigCB->isChecked();
+        m_pOptionState->classState.showOpSig = m_ClassWidgets.showOpSigCB->isChecked();
+        m_pOptionState->classState.showPackage = m_ClassWidgets.showPackageCB->isChecked();
         m_pOptionState->classState.defaultAttributeScope = (Uml::Visibility::Value) m_ClassWidgets.m_pAttribScopeCB->currentIndex();
         m_pOptionState->classState.defaultOperationScope = (Uml::Visibility::Value) m_ClassWidgets.m_pOperationScopeCB->currentIndex();
     }
@@ -470,17 +474,17 @@ void SettingsDlg::applyPage( KPageWidgetItem*item )
 
 void SettingsDlg::slotLineBClicked()
 {
-    m_UiWidgets.lineColorB -> setColor( Qt::red );
+    m_UiWidgets.lineColorB->setColor( Qt::red );
 }
 
 void SettingsDlg::slotFillBClicked()
 {
-    m_UiWidgets.fillColorB -> setColor( QColor(255, 255, 192) );
+    m_UiWidgets.fillColorB->setColor( QColor(255, 255, 192) );
 }
 
 void SettingsDlg::slotAutosaveCBClicked()
 {
-    m_GeneralWidgets.timeISB -> setEnabled( m_GeneralWidgets.autosaveCB -> isChecked() );
+    m_GeneralWidgets.timeISB->setEnabled( m_GeneralWidgets.autosaveCB->isChecked() );
 }
 
 QString SettingsDlg::getCodeGenerationLanguage()
