@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2010                                               *
+ *   copyright (C) 2003-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -12,6 +12,7 @@
 #include "entity.h"
 
 // app includes
+#include "debug_utils.h"
 #include "entityattribute.h"
 #include "uniqueconstraint.h"
 #include "foreignkeyconstraint.h"
@@ -28,7 +29,6 @@
 #include "umlcheckconstraintdialog.h"
 
 // kde includes
-#include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
@@ -58,7 +58,7 @@ UMLEntity::~UMLEntity()
 /**
  * Overloaded '==' operator.
  */
-bool UMLEntity::operator==(const UMLEntity& rhs )
+bool UMLEntity::operator==(const UMLEntity& rhs) const
 {
     return UMLClassifier::operator==(rhs);
 }
