@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2010                                               *
+ *   copyright (C) 2006-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -136,7 +136,7 @@ void UMLFolder::activateViews()
     }
     // Make sure we have a treeview item for each diagram.
     // It may happen that we are missing them after switching off tabbed widgets.
-    Settings::OptionState optionState = Settings::getOptionState();
+    Settings::OptionState optionState = Settings::optionState();
     if (optionState.generalState.tabdiagrams) {
         return;
     }
@@ -365,7 +365,7 @@ void UMLFolder::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
  */
 bool UMLFolder::loadDiagramsFromXMI(QDomNode& diagrams)
 {
-    const Settings::OptionState optionState = Settings::getOptionState();
+    const Settings::OptionState optionState = Settings::optionState();
     UMLDoc *umldoc = UMLApp::app()->document();
     bool totalSuccess = true;
     for (QDomElement diagram = diagrams.toElement(); !diagram.isNull();
