@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2010                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -34,6 +34,7 @@
 #include "widget_utils.h"
 #include "icon_utils.h"
 #include "model_utils.h"
+#include "debug_utils.h"
 // dialogs
 #include "classwizard.h"
 #include "codegenerationwizard.h"
@@ -42,13 +43,13 @@
 #include "importprojectdlg.h"
 #include "settingsdlg.h"
 #include "classimport.h"
-#include "refactoring/refactoringassistant.h"
+#include "refactoringassistant.h"
 // clipboard
 #include "umlclipboard.h"
 #include "umldragdata.h"
 // docgenerators
-#include "docgenerators/docbookgenerator.h"
-#include "docgenerators/xhtmlgenerator.h"
+#include "docbookgenerator.h"
+#include "xhtmlgenerator.h"
 
 // kde includes
 #include <kaction.h>
@@ -58,7 +59,6 @@
 #include <krecentfilesaction.h>
 #include <kconfig.h>
 #include <kcursor.h>
-#include <kdebug.h>
 #include <kfiledialog.h>
 #include <klocale.h>
 #include <kmenubar.h>
@@ -106,7 +106,7 @@ QMenu* UMLApp::findMenu(const QString& name)
     if (widget) {
         return dynamic_cast<QMenu*>(widget);
     }
-    uDebug() << "factory()->container(" << name << ") returns NULL";
+    DEBUG(DBG_SRC) << "factory()->container(" << name << ") returns NULL";
     return NULL;
 }
 
@@ -146,6 +146,8 @@ UMLApp::UMLApp(QWidget* parent) : KXmlGuiWindow(parent)
     initClip();
     readOptions();
 
+    DEBUG_REGISTER(DBG_SRC);
+
     //get a reference to the Code->Active Language and to the Diagram->Zoom menu
     m_langSelect = findMenu(QString("active_lang_menu") );
 
@@ -208,6 +210,7 @@ void UMLApp::setProgLangAction(Uml::Programming_Language pl, const QString& name
 /**
  * Initializes the KActions and the status bar of the application 
  * and calls setupGUI().
+ * Note: Check also the file umbrelloui.rc and add actions there too.
  */
 void UMLApp::initActions()
 {
@@ -673,7 +676,7 @@ void UMLApp::initView()
 
     m_layout = new QVBoxLayout;
     m_layout->setMargin(0);
-    if (Settings::getOptionState().generalState.tabdiagrams) {
+    if (Settings::optionState().generalState.tabdiagrams) {
         // Tabbed Diagram Representation
         m_layout->addWidget(m_tabWidget);
         m_viewStack->hide();
@@ -776,7 +779,7 @@ void UMLApp::saveOptions()
 
     UmbrelloSettings::setGeometry( size() );
 
-    Settings::OptionState& optionState = Settings::getOptionState();
+    Settings::OptionState& optionState = Settings::optionState();
 
     UmbrelloSettings::setUndo( optionState.generalState.undo );
     UmbrelloSettings::setTabdiagrams( optionState.generalState.tabdiagrams );
@@ -901,7 +904,7 @@ void UMLApp::readOptions()
  */
 void UMLApp::saveProperties(KConfigGroup & cfg)
 {
-    uDebug() << "******************* commented out - UNUSED?";
+    DEBUG(DBG_SRC) << "******************* commented out - UNUSED?";
     Q_UNUSED(cfg);
 /*
     if (m_doc->url().fileName() != i18n("Untitled") && !m_doc->isModified()) {
@@ -928,7 +931,7 @@ void UMLApp::saveProperties(KConfigGroup & cfg)
  */
 void UMLApp::readProperties(const KConfigGroup & cfg)     //:TODO: applyMainWindowSettings(const KConfigGroup& config, bool force = false)
 {
-    uDebug() << "******************* commented out - UNUSED?";
+    DEBUG(DBG_SRC) << "******************* commented out - UNUSED?";
     Q_UNUSED(cfg);
 /*
     QString filename = cfg.readPathEntry("filename", QString());
@@ -1599,7 +1602,7 @@ void UMLApp::slotCopyChanged()
  */
 void UMLApp::slotPrefs()
 {
-       Settings::OptionState& optionState = Settings::getOptionState();
+       Settings::OptionState& optionState = Settings::optionState();
 
        m_dlg = new SettingsDlg(this, &optionState);
        connect(m_dlg, SIGNAL( applyClicked() ), this, SLOT( slotApplyPrefs() ) );
@@ -1619,10 +1622,10 @@ void UMLApp::slotApplyPrefs()
 {
     if (m_dlg) {
         // we need this to sync both values
-        Settings::OptionState& optionState = Settings::getOptionState();
+        Settings::OptionState& optionState = Settings::optionState();
         bool stackBrowsing = (m_layout->indexOf(m_tabWidget) != -1);
         bool tabBrowsing = optionState.generalState.tabdiagrams;
-        uDebug() << "stackBrowsing=" << stackBrowsing << " / tabBrowsing=" << tabBrowsing;
+        DEBUG(DBG_SRC) << "stackBrowsing=" << stackBrowsing << " / tabBrowsing=" << tabBrowsing;
 
         if (stackBrowsing != tabBrowsing) {
             // Diagram Representation Modified
@@ -1735,7 +1738,7 @@ bool UMLApp::editCutCopy( bool bFromView )
  */
 void UMLApp::readOptionState()
 {
-    Settings::OptionState& optionState = Settings::getOptionState();
+    Settings::OptionState& optionState = Settings::optionState();
 
     UmbrelloSettings::self()->readConfig();
     optionState.generalState.undo = UmbrelloSettings::undo();
@@ -1843,10 +1846,10 @@ void UMLApp::viewCodeDocument(UMLClassifier* classifier)
             CodeDocument *cdoc = currentGen->findCodeDocumentByClassifier(classifier);
 
             if (cdoc) {
-                Settings::OptionState& optionState = Settings::getOptionState();
+                Settings::OptionState& optionState = Settings::optionState();
                 CodeViewerDialog * dialog = currentGen->getCodeViewerDialog(this,cdoc,optionState.codeViewerState);
                 dialog->exec();
-                optionState.codeViewerState = dialog->getState();
+                optionState.codeViewerState = dialog->state();
                 delete dialog;
                 dialog = NULL;
             } else {
@@ -2392,7 +2395,7 @@ void UMLApp::slotCloseDiagram(QWidget* tab)
  */
 Uml::Programming_Language UMLApp::defaultLanguage()
 {
-    Settings::OptionState& optionState = Settings::getOptionState();
+    Settings::OptionState& optionState = Settings::optionState();
     return optionState.generalState.defaultLanguage;
 }
 
@@ -2434,6 +2437,13 @@ void UMLApp::keyPressEvent(QKeyEvent *e)
         e->accept();
         break;
 
+    case Qt::Key_D:
+        if (e->modifiers() & Qt::ControlModifier) {  // Ctrl + D
+            DEBUG(DBG_SRC) << "Ctrl + D is pressed. Show debug config dialog...";
+            DEBUG_SHOW_FILTER();
+        }
+        break;
+
     default:
         e->ignore();
     }
@@ -2535,7 +2545,7 @@ void UMLApp::newDocument()
  */
 QWidget* UMLApp::mainViewWidget()
 {
-    Settings::OptionState& optionState = Settings::getOptionState();
+    Settings::OptionState& optionState = Settings::optionState();
     if ( optionState.generalState.tabdiagrams ) {
         return m_tabWidget;
     }
@@ -2554,12 +2564,12 @@ void UMLApp::setCurrentView(UMLView* view)
 {
     m_view = view;
     if (view == NULL) {
-        uDebug() << "view is NULL";
+        DEBUG(DBG_SRC) << "view is NULL";
         docWindow()->newDocumentation();
         return;
     }
 
-    Settings::OptionState optionState = Settings::getOptionState();
+    Settings::OptionState optionState = Settings::optionState();
     if (optionState.generalState.tabdiagrams) {
         int tabIndex = m_tabWidget->indexOf(view);
         if ((tabIndex < 0) && view->isOpen()) {
@@ -2582,7 +2592,9 @@ void UMLApp::setCurrentView(UMLView* view)
     if (lvitem) {
         m_listView->setCurrentItem(lvitem);
     }
-    uDebug() << "name=" << view->getName() << ", isOpen=" << view->isOpen() << ", id=" << ID2STR(view->getID());
+    DEBUG(DBG_SRC) << "name=" << view->getName()
+                   << ", isOpen=" << view->isOpen()
+                   << ", id=" << ID2STR(view->getID());
 }
 
 /**
@@ -2631,7 +2643,7 @@ void UMLApp::slotTabChanged(QWidget* tab)
  */
 void UMLApp::slotChangeTabLeft()
 {
-    //uDebug() << "currentIndex = " << m_tabWidget->currentIndex() << " of " << m_tabWidget->count();
+    //DEBUG(DBG_SRC) << "currentIndex = " << m_tabWidget->currentIndex() << " of " << m_tabWidget->count();
     if (m_tabWidget) {
         m_tabWidget->setCurrentIndex( m_tabWidget->currentIndex() - 1 );
         return;
@@ -2661,7 +2673,7 @@ void UMLApp::slotChangeTabLeft()
  */
 void UMLApp::slotChangeTabRight()
 {
-    //uDebug() << "currentIndex = " << m_tabWidget->currentIndex() << " of " << m_tabWidget->count();
+    //DEBUG(DBG_SRC) << "currentIndex = " << m_tabWidget->currentIndex() << " of " << m_tabWidget->count();
     if (m_tabWidget) {
         m_tabWidget->setCurrentIndex( m_tabWidget->currentIndex() + 1 );
         return;
@@ -2693,7 +2705,7 @@ static void showTabTexts(KTabWidget* tabWidget)
     for (int i = 0; i < tabWidget->count(); ++i) {
         out += " <" + tabWidget->tabText(i) + '>';
     }
-    uDebug() << out;
+    DEBUG(DBG_SRC) << out;
 }
 */
 
@@ -2702,7 +2714,7 @@ static void showTabTexts(KTabWidget* tabWidget)
  */
 void UMLApp::slotMoveTabLeft()
 {
-    //uDebug() << "currentIndex = " << m_tabWidget->currentIndex() << " of " << m_tabWidget->count();
+    //DEBUG(DBG_SRC) << "currentIndex = " << m_tabWidget->currentIndex() << " of " << m_tabWidget->count();
     //showTabTexts(m_tabWidget);
     int from = m_tabWidget->currentIndex();
     int to   = -1;
@@ -2720,7 +2732,7 @@ void UMLApp::slotMoveTabLeft()
  */
 void UMLApp::slotMoveTabRight()
 {
-    //uDebug() << "currentIndex = " << m_tabWidget->currentIndex() << " of " << m_tabWidget->count();
+    //DEBUG(DBG_SRC) << "currentIndex = " << m_tabWidget->currentIndex() << " of " << m_tabWidget->count();
     //showTabTexts(m_tabWidget);
     int from = m_tabWidget->currentIndex();
     int to   = -1;
@@ -2780,7 +2792,7 @@ void UMLApp::clearUndoStack()
  */
 void UMLApp::undo()
 {
-    uDebug() << m_pUndoStack->undoText() << " [" << m_pUndoStack->count() << "]";
+    DEBUG(DBG_SRC) << m_pUndoStack->undoText() << " [" << m_pUndoStack->count() << "]";
     m_pUndoStack->undo();
 
     if (m_pUndoStack->canUndo()) {
@@ -2798,7 +2810,7 @@ void UMLApp::undo()
  */
 void UMLApp::redo()
 {
-    uDebug() << m_pUndoStack->redoText() << " [" << m_pUndoStack->count() << "]";
+    DEBUG(DBG_SRC) << m_pUndoStack->redoText() << " [" << m_pUndoStack->count() << "]";
     m_pUndoStack->redo();
 
     if (m_pUndoStack->canRedo()) {
@@ -2818,7 +2830,7 @@ void UMLApp::executeCommand(QUndoCommand* cmd)
 {
     if (cmd != NULL) {
         m_pUndoStack->push(cmd);
-        uDebug() << cmd->text() << " [" << m_pUndoStack->count() << "]";
+        DEBUG(DBG_SRC) << cmd->text() << " [" << m_pUndoStack->count() << "]";
     }
 
     UMLApp::app()->enableUndo(true);
